@@ -1,7 +1,4 @@
-#ifndef NEXT_PERMUTATION_H
-#define NEXT_PERMUTATION_H
+#pragma once
 
 void nextFullPerm(int *const myArray, int maxInd);
 void nextPartialPerm(int *const myArray, int m1, int maxInd);
-
-#endif
